Package: finalsize
Title: Calculate the Final Size of an Epidemic
Version: 0.2.1
Authors@R: c(
    person("Pratik", "Gupte", , "pratik.gupte@lshtm.ac.uk", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-5294-7819")),
    person("Edwin", "Van Leeuwen", , "edwin.vanleeuwen@ukhsa.gov.uk", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-2383-5305")),
    person("Adam", "Kucharski", , "adam.kucharski@lshtm.ac.uk", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0001-8814-9421")),
    person("Rosalind", "Eggo", , "r.eggo@lshtm.ac.uk", role = "ctb",
           comment = c(ORCID = "0000-0002-0362-6717")),
    person("Hugo", "Gruson", , "hugo.gruson@data.org", role = "ctb",
           comment = c(ORCID = "0000-0002-4094-1476")),
    person("Thibaut", "Jombart", , "thibaut@data.org", role = "ctb",
           comment = c(ORCID = "0000-0003-3796-2097")),
    person("Andree", "Valle-Campos", , "andree.valle-campos@lshtm.ac.uk", role = "ctb",
           comment = c(ORCID = "0000-0002-7779-481X")),
    person("Joshua W.", "Lambert", , "joshua.lambert@lshtm.ac.uk", role = "rev",
           comment = c(ORCID = "0000-0001-5218-3046"))
  )
Description: Calculate the final size of a
    susceptible-infectious-recovered epidemic in a population with
    demographic variation in contact patterns and susceptibility to
    disease, as discussed in Miller (2012)
    <doi:10.1007/s11538-012-9749-6>.
License: MIT + file LICENSE
URL: https://github.com/epiverse-trace/finalsize,
        https://epiverse-trace.github.io/finalsize/
BugReports: https://github.com/epiverse-trace/finalsize/issues
Depends: R (>= 2.10)
Imports: checkmate, Rcpp
Suggests: bookdown, colorspace, dplyr, forcats, ggplot2, ggtext, knitr,
        purrr, rmarkdown, scales, socialmixr, spelling, testthat (>=
        3.0.0), tibble, tidyr, xml2
LinkingTo: Rcpp, RcppEigen
VignetteBuilder: knitr
Config/Needs/website: epiverse-trace/epiversetheme
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
LazyData: true
RoxygenNote: 7.2.3
NeedsCompilation: yes
Packaged: 2024-04-09 16:21:41 UTC; lshpg6
Author: Pratik Gupte [aut, cre, cph] (<https://orcid.org/0000-0001-5294-7819>),
  Edwin Van Leeuwen [aut, cph] (<https://orcid.org/0000-0002-2383-5305>),
  Adam Kucharski [aut, cph] (<https://orcid.org/0000-0001-8814-9421>),
  Rosalind Eggo [ctb] (<https://orcid.org/0000-0002-0362-6717>),
  Hugo Gruson [ctb] (<https://orcid.org/0000-0002-4094-1476>),
  Thibaut Jombart [ctb] (<https://orcid.org/0000-0003-3796-2097>),
  Andree Valle-Campos [ctb] (<https://orcid.org/0000-0002-7779-481X>),
  Joshua W. Lambert [rev] (<https://orcid.org/0000-0001-5218-3046>)
Maintainer: Pratik Gupte <pratik.gupte@lshtm.ac.uk>
Repository: CRAN
Date/Publication: 2024-04-09 16:40:06 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 18:08:01 UTC; unix
Archs: finalsize.so.dSYM
